@@ -200,8 +200,8 @@ async def main():
             nonlocal status_count
             status_count += 1
             logger.info(
-                f"Status #{status_count}: Temp={status.dhwTemperature}°F, "
-                f"Mode={status.operationMode}"
+                f"Status #{status_count}: Temp={status.dhw_temperature}°F, "
+                f"Mode={status.operation_mode}"
             )
 
         # Create resilient MQTT client
