@@ -1,3 +1,9 @@
+"""Navien NWP500 water heater control library.
+
+This package provides Python bindings for Navien Smart Control API and MQTT
+communication for NWP500 heat pump water heaters.
+"""
+
 from importlib.metadata import (
     PackageNotFoundError,
     version,
@@ -14,17 +20,12 @@ finally:
 
 # Export main components
 from nwp500.api_client import (
-    APIError,
     NavienAPIClient,
 )
 from nwp500.auth import (
-    AuthenticationError,
     AuthenticationResponse,
     AuthTokens,
-    InvalidCredentialsError,
     NavienAuthClient,
-    TokenExpiredError,
-    TokenRefreshError,
     UserInfo,
     authenticate,
     refresh_access_token,
@@ -43,6 +44,27 @@ from nwp500.events import (
     EventEmitter,
     EventListener,
 )
+from nwp500.exceptions import (
+    APIError,
+    AuthenticationError,
+    DeviceError,
+    DeviceNotFoundError,
+    DeviceOfflineError,
+    DeviceOperationError,
+    InvalidCredentialsError,
+    MqttConnectionError,
+    MqttCredentialsError,
+    MqttError,
+    MqttNotConnectedError,
+    MqttPublishError,
+    MqttSubscriptionError,
+    Nwp500Error,
+    ParameterValidationError,
+    RangeValidationError,
+    TokenExpiredError,
+    TokenRefreshError,
+    ValidationError,
+)
 from nwp500.models import (
     CurrentOperationMode,
     Device,
@@ -50,7 +72,7 @@ from nwp500.models import (
     DeviceInfo,
     DeviceStatus,
     DhwOperationSetting,
-    EnergyUsageData,
+    EnergyUsageDay,
     EnergyUsageResponse,
     EnergyUsageTotal,
     FirmwareInfo,
@@ -61,6 +83,7 @@ from nwp500.models import (
     TemperatureUnit,
     TOUInfo,
     TOUSchedule,
+    fahrenheit_to_half_celsius,
 )
 from nwp500.mqtt_client import NavienMqttClient
 from nwp500.mqtt_utils import MqttConnectionConfig, PeriodicRequestType
@@ -84,26 +107,43 @@ __all__ = [
     "TemperatureUnit",
     "MqttRequest",
     "MqttCommand",
-    "EnergyUsageData",
-    "MonthlyEnergyData",
     "EnergyUsageTotal",
+    "EnergyUsageDay",
+    "MonthlyEnergyData",
     "EnergyUsageResponse",
+    # Conversion utilities
+    "fahrenheit_to_half_celsius",
     # Authentication
     "NavienAuthClient",
     "AuthenticationResponse",
     "AuthTokens",
     "UserInfo",
+    "authenticate",
+    "refresh_access_token",
+    # Exceptions (all in one place)
+    "Nwp500Error",
     "AuthenticationError",
     "InvalidCredentialsError",
     "TokenExpiredError",
     "TokenRefreshError",
-    "authenticate",
-    "refresh_access_token",
+    "APIError",
+    "MqttError",
+    "MqttConnectionError",
+    "MqttNotConnectedError",
+    "MqttPublishError",
+    "MqttSubscriptionError",
+    "MqttCredentialsError",
+    "ValidationError",
+    "ParameterValidationError",
+    "RangeValidationError",
+    "DeviceError",
+    "DeviceNotFoundError",
+    "DeviceOfflineError",
+    "DeviceOperationError",
     # Constants
     "constants",
     # API Client
     "NavienAPIClient",
-    "APIError",
     # MQTT Client
     "NavienMqttClient",
     "MqttConnectionConfig",
