@@ -9,12 +9,9 @@ from typing import Any, Optional
 
 import aiohttp
 
-from .auth import (
-    AuthenticationError,
-    NavienAuthClient,
-    TokenRefreshError,
-)
+from .auth import NavienAuthClient
 from .config import API_BASE_URL
+from .exceptions import APIError, AuthenticationError, TokenRefreshError
 from .models import Device, FirmwareInfo, TOUInfo
 
 __author__ = "Emmanuel Levijarvi"
@@ -24,32 +21,9 @@ __license__ = "MIT"
 _logger = logging.getLogger(__name__)
 
 
-class APIError(Exception):
-    """Raised when API returns an error response.
-
-    Attributes:
-        message: Error message describing the failure
-        code: HTTP or API error code
-        response: Complete API response dictionary
-    """
-
-    def __init__(
-        self,
-        message: str,
-        code: Optional[int] = None,
-        response: Optional[dict[str, Any]] = None,
-    ):
-        """Initialize API error.
-
-        Args:
-            message: Error message describing the failure
-            code: HTTP or API error code
-            response: Complete API response dictionary
-        """
-        self.message = message
-        self.code = code
-        self.response = response
-        super().__init__(self.message)
+__all__ = [
+    "NavienAPIClient",
+]
 
 
 class NavienAPIClient:
@@ -96,9 +70,11 @@ class NavienAPIClient:
 
         self.base_url = base_url.rstrip("/")
         self._auth_client = auth_client
-        self._session: aiohttp.ClientSession = session or auth_client._session  # type: ignore[assignment]
-        if self._session is None:
+        self._auth_client = auth_client
+        _session = session or auth_client._session
+        if _session is None:
             raise ValueError("auth_client must have an active session")
+        self._session = _session
         self._owned_session = (
             False  # Never own session when auth_client is provided
         )
@@ -211,7 +187,7 @@ class NavienAPIClient:
 
         except aiohttp.ClientError as e:
             _logger.error(f"Network error: {e}")
-            raise APIError(f"Network error: {str(e)}")
+            raise APIError(f"Network error: {str(e)}") from e
 
     # Device Management Endpoints
 
@@ -246,7 +222,7 @@ class NavienAPIClient:
         )
 
         devices_data = response.get("data", [])
-        devices = [Device.from_dict(d) for d in devices_data]
+        devices = [Device.model_validate(d) for d in devices_data]
 
         _logger.info(f"Retrieved {len(devices)} device(s)")
         return devices
@@ -282,7 +258,7 @@ class NavienAPIClient:
         )
 
         data = response.get("data", {})
-        device = Device.from_dict(data)
+        device = Device.model_validate(data)
 
         _logger.info(
             f"Retrieved info for device: {device.device_info.device_name}"
@@ -321,7 +297,7 @@ class NavienAPIClient:
 
         data = response.get("data", {})
         firmwares_data = data.get("firmwares", [])
-        firmwares = [FirmwareInfo.from_dict(f) for f in firmwares_data]
+        firmwares = [FirmwareInfo.model_validate(f) for f in firmwares_data]
 
         _logger.info(f"Retrieved firmware info: {len(firmwares)} firmware(s)")
         return firmwares
@@ -365,7 +341,7 @@ class NavienAPIClient:
         )
 
         data = response.get("data", {})
-        tou_info = TOUInfo.from_dict(data)
+        tou_info = TOUInfo.model_validate(data)
 
         _logger.info("Retrieved TOU info for device")
         return tou_info
