@@ -3,7 +3,6 @@
 import asyncio
 import json
 import logging
-from dataclasses import asdict
 from typing import Any, Optional
 
 from nwp500 import Device, DeviceFeature, DeviceStatus, NavienMqttClient
@@ -54,7 +53,9 @@ async def handle_status_request(mqtt: NavienMqttClient, device: Device) -> None:
         if not future.done():
             print(
                 json.dumps(
-                    asdict(status), indent=2, default=_json_default_serializer
+                    status.model_dump(),
+                    indent=2,
+                    default=_json_default_serializer,
                 )
             )
             future.set_result(None)
@@ -126,7 +127,9 @@ async def handle_device_info_request(
         if not future.done():
             print(
                 json.dumps(
-                    asdict(info), indent=2, default=_json_default_serializer
+                    info.model_dump(),
+                    indent=2,
+                    default=_json_default_serializer,
                 )
             )
             future.set_result(None)
@@ -225,7 +228,7 @@ async def handle_set_mode_request(
                 status = responses[0]
                 print(
                     json.dumps(
-                        asdict(status),
+                        status.model_dump(),
                         indent=2,
                         default=_json_default_serializer,
                     )
@@ -255,7 +258,7 @@ async def handle_set_mode_request(
 
 
 async def handle_set_dhw_temp_request(
-    mqtt: NavienMqttClient, device: Device, temperature: int
+    mqtt: NavienMqttClient, device: Device, temperature: float
 ) -> None:
     """
     Set DHW target temperature and display the response.
@@ -263,14 +266,13 @@ async def handle_set_dhw_temp_request(
     Args:
         mqtt: MQTT client instance
         device: Device to control
-        temperature: Target temperature in Fahrenheit (display value)
+        temperature: Target temperature in Fahrenheit (95-150°F)
     """
     # Validate temperature range
-    # Based on MQTT client documentation: display range approximately 115-150°F
-    if temperature < 115 or temperature > 150:
+    if temperature < 95 or temperature > 150:
         _logger.error(
             f"Temperature {temperature}°F is out of range. "
-            f"Valid range: 115-150°F"
+            f"Valid range: 95-150°F"
         )
         return
 
@@ -290,8 +292,8 @@ async def handle_set_dhw_temp_request(
     try:
         _logger.info(f"Setting DHW target temperature to {temperature}°F...")
 
-        # Send the temperature change command using display temperature
-        await mqtt.set_dhw_temperature_display(device, temperature)
+        # Send the temperature change command
+        await mqtt.set_dhw_temperature(device, temperature)
 
         # Wait for status response (temperature change confirmation)
         try:
@@ -301,7 +303,7 @@ async def handle_set_dhw_temp_request(
                 status = responses[0]
                 print(
                     json.dumps(
-                        asdict(status),
+                        status.model_dump(),
                         indent=2,
                         default=_json_default_serializer,
                     )
@@ -601,7 +603,7 @@ async def handle_set_tou_enabled_request(
                 status = responses[0]
                 print(
                     json.dumps(
-                        asdict(status),
+                        status.model_dump(),
                         indent=2,
                         default=_json_default_serializer,
                     )
